@@ -58,7 +58,11 @@ pseudoRes <- function(m, ncores = 1)
           }
         }
         oldDoPar <- doFuture::registerDoFuture()
-        future::plan(future::multisession, workers = ncores)
+        if (Sys.getenv("CI") == "true" && grepl("macOS", Sys.getenv("RUNNER_OS"))) {
+          future::plan(future::sequential)
+        } else {
+          future::plan(future::multisession, workers = ncores)
+        }
         on.exit(with(oldDoPar, foreach::setDoPar(fun=fun, data=data, info=info)), add = TRUE)
         # hack so that foreach %dorng% can find internal momentuHMM variables without using ::: (forbidden by CRAN)
         progBar <- progBar
